@@ -5,6 +5,6 @@ import os
 DEBUGGING = False # TODO: False
 
 PROGRAM_NAME = 'objbrowser'
-PROGRAM_VERSION = '0.9.4'
+PROGRAM_VERSION = '1.0.0a'
+PROGRAM_URL = 'https://github.com/titusjan/objbrowser'
 PROGRAM_DIRECTORY = os.path.abspath(os.path.dirname(__file__))
-#IMAGE_DIRECTORY = PROGRAM_DIRECTORY + '/images/'
